capi

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 15, 2026 License: CC0-1.0 Imports: 2 Imported by: 0

Documentation

Overview

Desktop builds require CGO_CFLAGS and CGO_LDFLAGS pointing to a JDK:

export CGO_CFLAGS="-I$JAVA_HOME/include -I$JAVA_HOME/include/linux"
export CGO_LDFLAGS="-L$JAVA_HOME/lib/server -ljvm"

Index

Constants

const (
	JNI_OK               = 0
	JNI_ERR              = -1
	JNI_EDETACHED        = -2
	JNI_EVERSION         = -3
	JNI_ENOMEM           = -4
	JNI_EEXIST           = -5
	JNI_EINVAL           = -6
	JNI_VERSION_1_1      = 0x00010001
	JNI_VERSION_1_2      = 0x00010002
	JNI_VERSION_1_4      = 0x00010004
	JNI_VERSION_1_6      = 0x00010006
	JNI_VERSION_1_8      = 0x00010008
	JNI_VERSION_9        = 0x00090000
	JNI_VERSION_10       = 0x000a0000
	JNI_VERSION_19       = 0x00130000
	JNI_VERSION_20       = 0x00140000
	JNI_VERSION_21       = 0x00150000
	JNI_COMMIT           = 1
	JNI_ABORT            = 2
	JNI_FALSE            = 0
	JNI_TRUE             = 1
	JNIInvalidRefType    = 0
	JNILocalRefType      = 1
	JNIGlobalRefType     = 2
	JNIWeakGlobalRefType = 3
)

Variables

This section is empty.

Functions

func AllocObject

func AllocObject(env *C.JNIEnv, p0 C.jclass) C.jobject

AllocObject wraps the JNI AllocObject function via vtable dispatch.

func AttachCurrentThread

func AttachCurrentThread(vm *C.JavaVM, p0 **C.JNIEnv, p1 unsafe.Pointer) C.jint

AttachCurrentThread wraps the JNI AttachCurrentThread function via vtable dispatch.

func AttachCurrentThreadAsDaemon

func AttachCurrentThreadAsDaemon(vm *C.JavaVM, p0 **C.JNIEnv, p1 unsafe.Pointer) C.jint

AttachCurrentThreadAsDaemon wraps the JNI AttachCurrentThreadAsDaemon function via vtable dispatch.

func CallBooleanMethodA

func CallBooleanMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jboolean

CallBooleanMethodA wraps the JNI CallBooleanMethodA function via vtable dispatch.

func CallByteMethodA

func CallByteMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jbyte

CallByteMethodA wraps the JNI CallByteMethodA function via vtable dispatch.

func CallCharMethodA

func CallCharMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jchar

CallCharMethodA wraps the JNI CallCharMethodA function via vtable dispatch.

func CallDoubleMethodA

func CallDoubleMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jdouble

CallDoubleMethodA wraps the JNI CallDoubleMethodA function via vtable dispatch.

func CallFloatMethodA

func CallFloatMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jfloat

CallFloatMethodA wraps the JNI CallFloatMethodA function via vtable dispatch.

func CallIntMethodA

func CallIntMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jint

CallIntMethodA wraps the JNI CallIntMethodA function via vtable dispatch.

func CallLongMethodA

func CallLongMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jlong

CallLongMethodA wraps the JNI CallLongMethodA function via vtable dispatch.

func CallNonvirtualBooleanMethodA

func CallNonvirtualBooleanMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jboolean

CallNonvirtualBooleanMethodA wraps the JNI CallNonvirtualBooleanMethodA function via vtable dispatch.

func CallNonvirtualByteMethodA

func CallNonvirtualByteMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jbyte

CallNonvirtualByteMethodA wraps the JNI CallNonvirtualByteMethodA function via vtable dispatch.

func CallNonvirtualCharMethodA

func CallNonvirtualCharMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jchar

CallNonvirtualCharMethodA wraps the JNI CallNonvirtualCharMethodA function via vtable dispatch.

func CallNonvirtualDoubleMethodA

func CallNonvirtualDoubleMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jdouble

CallNonvirtualDoubleMethodA wraps the JNI CallNonvirtualDoubleMethodA function via vtable dispatch.

func CallNonvirtualFloatMethodA

func CallNonvirtualFloatMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jfloat

CallNonvirtualFloatMethodA wraps the JNI CallNonvirtualFloatMethodA function via vtable dispatch.

func CallNonvirtualIntMethodA

func CallNonvirtualIntMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jint

CallNonvirtualIntMethodA wraps the JNI CallNonvirtualIntMethodA function via vtable dispatch.

func CallNonvirtualLongMethodA

func CallNonvirtualLongMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jlong

CallNonvirtualLongMethodA wraps the JNI CallNonvirtualLongMethodA function via vtable dispatch.

func CallNonvirtualObjectMethodA

func CallNonvirtualObjectMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jobject

CallNonvirtualObjectMethodA wraps the JNI CallNonvirtualObjectMethodA function via vtable dispatch.

func CallNonvirtualShortMethodA

func CallNonvirtualShortMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jshort

CallNonvirtualShortMethodA wraps the JNI CallNonvirtualShortMethodA function via vtable dispatch.

func CallNonvirtualVoidMethodA

func CallNonvirtualVoidMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue)

CallNonvirtualVoidMethodA wraps the JNI CallNonvirtualVoidMethodA function via vtable dispatch.

func CallObjectMethodA

func CallObjectMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jobject

CallObjectMethodA wraps the JNI CallObjectMethodA function via vtable dispatch.

func CallShortMethodA

func CallShortMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jshort

CallShortMethodA wraps the JNI CallShortMethodA function via vtable dispatch.

func CallStaticBooleanMethodA

func CallStaticBooleanMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jboolean

CallStaticBooleanMethodA wraps the JNI CallStaticBooleanMethodA function via vtable dispatch.

func CallStaticByteMethodA

func CallStaticByteMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jbyte

CallStaticByteMethodA wraps the JNI CallStaticByteMethodA function via vtable dispatch.

func CallStaticCharMethodA

func CallStaticCharMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jchar

CallStaticCharMethodA wraps the JNI CallStaticCharMethodA function via vtable dispatch.

func CallStaticDoubleMethodA

func CallStaticDoubleMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jdouble

CallStaticDoubleMethodA wraps the JNI CallStaticDoubleMethodA function via vtable dispatch.

func CallStaticFloatMethodA

func CallStaticFloatMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jfloat

CallStaticFloatMethodA wraps the JNI CallStaticFloatMethodA function via vtable dispatch.

func CallStaticIntMethodA

func CallStaticIntMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jint

CallStaticIntMethodA wraps the JNI CallStaticIntMethodA function via vtable dispatch.

func CallStaticLongMethodA

func CallStaticLongMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jlong

CallStaticLongMethodA wraps the JNI CallStaticLongMethodA function via vtable dispatch.

func CallStaticObjectMethodA

func CallStaticObjectMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jobject

CallStaticObjectMethodA wraps the JNI CallStaticObjectMethodA function via vtable dispatch.

func CallStaticShortMethodA

func CallStaticShortMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jshort

CallStaticShortMethodA wraps the JNI CallStaticShortMethodA function via vtable dispatch.

func CallStaticVoidMethodA

func CallStaticVoidMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue)

CallStaticVoidMethodA wraps the JNI CallStaticVoidMethodA function via vtable dispatch.

func CallVoidMethodA

func CallVoidMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue)

CallVoidMethodA wraps the JNI CallVoidMethodA function via vtable dispatch.

func DefineClass

func DefineClass(env *C.JNIEnv, p0 *C.char, p1 C.jobject, p2 *C.jbyte, p3 C.jsize) C.jclass

DefineClass wraps the JNI DefineClass function via vtable dispatch.

func DeleteGlobalRef

func DeleteGlobalRef(env *C.JNIEnv, p0 C.jobject)

DeleteGlobalRef wraps the JNI DeleteGlobalRef function via vtable dispatch.

func DeleteLocalRef

func DeleteLocalRef(env *C.JNIEnv, p0 C.jobject)

DeleteLocalRef wraps the JNI DeleteLocalRef function via vtable dispatch.

func DeleteWeakGlobalRef

func DeleteWeakGlobalRef(env *C.JNIEnv, p0 C.jweak)

DeleteWeakGlobalRef wraps the JNI DeleteWeakGlobalRef function via vtable dispatch.

func DestroyJavaVM

func DestroyJavaVM(vm *C.JavaVM) C.jint

DestroyJavaVM wraps the JNI DestroyJavaVM function via vtable dispatch.

func DetachCurrentThread

func DetachCurrentThread(vm *C.JavaVM) C.jint

DetachCurrentThread wraps the JNI DetachCurrentThread function via vtable dispatch.

func EnsureLocalCapacity

func EnsureLocalCapacity(env *C.JNIEnv, p0 C.jint) C.jint

EnsureLocalCapacity wraps the JNI EnsureLocalCapacity function via vtable dispatch.

func ExceptionCheck

func ExceptionCheck(env *C.JNIEnv) C.jboolean

ExceptionCheck wraps the JNI ExceptionCheck function via vtable dispatch.

func ExceptionClear

func ExceptionClear(env *C.JNIEnv)

ExceptionClear wraps the JNI ExceptionClear function via vtable dispatch.

func ExceptionDescribe

func ExceptionDescribe(env *C.JNIEnv)

ExceptionDescribe wraps the JNI ExceptionDescribe function via vtable dispatch.

func ExceptionOccurred

func ExceptionOccurred(env *C.JNIEnv) C.jthrowable

ExceptionOccurred wraps the JNI ExceptionOccurred function via vtable dispatch.

func FatalError

func FatalError(env *C.JNIEnv, p0 *C.char)

FatalError wraps the JNI FatalError function via vtable dispatch.

func FindClass

func FindClass(env *C.JNIEnv, p0 *C.char) C.jclass

FindClass wraps the JNI FindClass function via vtable dispatch.

func FromReflectedField

func FromReflectedField(env *C.JNIEnv, p0 C.jobject) C.jfieldID

FromReflectedField wraps the JNI FromReflectedField function via vtable dispatch.

func FromReflectedMethod

func FromReflectedMethod(env *C.JNIEnv, p0 C.jobject) C.jmethodID

FromReflectedMethod wraps the JNI FromReflectedMethod function via vtable dispatch.

func GetArrayLength

func GetArrayLength(env *C.JNIEnv, p0 C.jarray) C.jsize

GetArrayLength wraps the JNI GetArrayLength function via vtable dispatch.

func GetBooleanArrayElements

func GetBooleanArrayElements(env *C.JNIEnv, p0 C.jbooleanArray, p1 *C.jboolean) *C.jboolean

GetBooleanArrayElements wraps the JNI GetBooleanArrayElements function via vtable dispatch.

func GetBooleanArrayRegion

func GetBooleanArrayRegion(env *C.JNIEnv, p0 C.jbooleanArray, p1 C.jsize, p2 C.jsize, p3 *C.jboolean)

GetBooleanArrayRegion wraps the JNI GetBooleanArrayRegion function via vtable dispatch.

func GetBooleanField

func GetBooleanField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jboolean

GetBooleanField wraps the JNI GetBooleanField function via vtable dispatch.

func GetByteArrayElements

func GetByteArrayElements(env *C.JNIEnv, p0 C.jbyteArray, p1 *C.jboolean) *C.jbyte

GetByteArrayElements wraps the JNI GetByteArrayElements function via vtable dispatch.

func GetByteArrayRegion

func GetByteArrayRegion(env *C.JNIEnv, p0 C.jbyteArray, p1 C.jsize, p2 C.jsize, p3 *C.jbyte)

GetByteArrayRegion wraps the JNI GetByteArrayRegion function via vtable dispatch.

func GetByteField

func GetByteField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jbyte

GetByteField wraps the JNI GetByteField function via vtable dispatch.

func GetCharArrayElements

func GetCharArrayElements(env *C.JNIEnv, p0 C.jcharArray, p1 *C.jboolean) *C.jchar

GetCharArrayElements wraps the JNI GetCharArrayElements function via vtable dispatch.

func GetCharArrayRegion

func GetCharArrayRegion(env *C.JNIEnv, p0 C.jcharArray, p1 C.jsize, p2 C.jsize, p3 *C.jchar)

GetCharArrayRegion wraps the JNI GetCharArrayRegion function via vtable dispatch.

func GetCharField

func GetCharField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jchar

GetCharField wraps the JNI GetCharField function via vtable dispatch.

func GetDirectBufferAddress

func GetDirectBufferAddress(env *C.JNIEnv, p0 C.jobject) unsafe.Pointer

GetDirectBufferAddress wraps the JNI GetDirectBufferAddress function via vtable dispatch.

func GetDirectBufferCapacity

func GetDirectBufferCapacity(env *C.JNIEnv, p0 C.jobject) C.jlong

GetDirectBufferCapacity wraps the JNI GetDirectBufferCapacity function via vtable dispatch.

func GetDoubleArrayElements

func GetDoubleArrayElements(env *C.JNIEnv, p0 C.jdoubleArray, p1 *C.jboolean) *C.jdouble

GetDoubleArrayElements wraps the JNI GetDoubleArrayElements function via vtable dispatch.

func GetDoubleArrayRegion

func GetDoubleArrayRegion(env *C.JNIEnv, p0 C.jdoubleArray, p1 C.jsize, p2 C.jsize, p3 *C.jdouble)

GetDoubleArrayRegion wraps the JNI GetDoubleArrayRegion function via vtable dispatch.

func GetDoubleField

func GetDoubleField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jdouble

GetDoubleField wraps the JNI GetDoubleField function via vtable dispatch.

func GetEnv

func GetEnv(vm *C.JavaVM, p0 *unsafe.Pointer, p1 C.jint) C.jint

GetEnv wraps the JNI GetEnv function via vtable dispatch.

func GetFieldID

func GetFieldID(env *C.JNIEnv, p0 C.jclass, p1 *C.char, p2 *C.char) C.jfieldID

GetFieldID wraps the JNI GetFieldID function via vtable dispatch.

func GetFloatArrayElements

func GetFloatArrayElements(env *C.JNIEnv, p0 C.jfloatArray, p1 *C.jboolean) *C.jfloat

GetFloatArrayElements wraps the JNI GetFloatArrayElements function via vtable dispatch.

func GetFloatArrayRegion

func GetFloatArrayRegion(env *C.JNIEnv, p0 C.jfloatArray, p1 C.jsize, p2 C.jsize, p3 *C.jfloat)

GetFloatArrayRegion wraps the JNI GetFloatArrayRegion function via vtable dispatch.

func GetFloatField

func GetFloatField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jfloat

GetFloatField wraps the JNI GetFloatField function via vtable dispatch.

func GetIntArrayElements

func GetIntArrayElements(env *C.JNIEnv, p0 C.jintArray, p1 *C.jboolean) *C.jint

GetIntArrayElements wraps the JNI GetIntArrayElements function via vtable dispatch.

func GetIntArrayRegion

func GetIntArrayRegion(env *C.JNIEnv, p0 C.jintArray, p1 C.jsize, p2 C.jsize, p3 *C.jint)

GetIntArrayRegion wraps the JNI GetIntArrayRegion function via vtable dispatch.

func GetIntField

func GetIntField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jint

GetIntField wraps the JNI GetIntField function via vtable dispatch.

func GetLongArrayElements

func GetLongArrayElements(env *C.JNIEnv, p0 C.jlongArray, p1 *C.jboolean) *C.jlong

GetLongArrayElements wraps the JNI GetLongArrayElements function via vtable dispatch.

func GetLongArrayRegion

func GetLongArrayRegion(env *C.JNIEnv, p0 C.jlongArray, p1 C.jsize, p2 C.jsize, p3 *C.jlong)

GetLongArrayRegion wraps the JNI GetLongArrayRegion function via vtable dispatch.

func GetLongField

func GetLongField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jlong

GetLongField wraps the JNI GetLongField function via vtable dispatch.

func GetMethodID

func GetMethodID(env *C.JNIEnv, p0 C.jclass, p1 *C.char, p2 *C.char) C.jmethodID

GetMethodID wraps the JNI GetMethodID function via vtable dispatch.

func GetObjectArrayElement

func GetObjectArrayElement(env *C.JNIEnv, p0 C.jobjectArray, p1 C.jsize) C.jobject

GetObjectArrayElement wraps the JNI GetObjectArrayElement function via vtable dispatch.

func GetObjectClass

func GetObjectClass(env *C.JNIEnv, p0 C.jobject) C.jclass

GetObjectClass wraps the JNI GetObjectClass function via vtable dispatch.

func GetObjectField

func GetObjectField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jobject

GetObjectField wraps the JNI GetObjectField function via vtable dispatch.

func GetObjectRefType

func GetObjectRefType(env *C.JNIEnv, p0 C.jobject) C.jobjectRefType

GetObjectRefType wraps the JNI GetObjectRefType function via vtable dispatch.

func GetPrimitiveArrayCritical

func GetPrimitiveArrayCritical(env *C.JNIEnv, p0 C.jarray, p1 *C.jboolean) unsafe.Pointer

GetPrimitiveArrayCritical wraps the JNI GetPrimitiveArrayCritical function via vtable dispatch.

func GetShortArrayElements

func GetShortArrayElements(env *C.JNIEnv, p0 C.jshortArray, p1 *C.jboolean) *C.jshort

GetShortArrayElements wraps the JNI GetShortArrayElements function via vtable dispatch.

func GetShortArrayRegion

func GetShortArrayRegion(env *C.JNIEnv, p0 C.jshortArray, p1 C.jsize, p2 C.jsize, p3 *C.jshort)

GetShortArrayRegion wraps the JNI GetShortArrayRegion function via vtable dispatch.

func GetShortField

func GetShortField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jshort

GetShortField wraps the JNI GetShortField function via vtable dispatch.

func GetStaticBooleanField

func GetStaticBooleanField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jboolean

GetStaticBooleanField wraps the JNI GetStaticBooleanField function via vtable dispatch.

func GetStaticByteField

func GetStaticByteField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jbyte

GetStaticByteField wraps the JNI GetStaticByteField function via vtable dispatch.

func GetStaticCharField

func GetStaticCharField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jchar

GetStaticCharField wraps the JNI GetStaticCharField function via vtable dispatch.

func GetStaticDoubleField

func GetStaticDoubleField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jdouble

GetStaticDoubleField wraps the JNI GetStaticDoubleField function via vtable dispatch.

func GetStaticFieldID

func GetStaticFieldID(env *C.JNIEnv, p0 C.jclass, p1 *C.char, p2 *C.char) C.jfieldID

GetStaticFieldID wraps the JNI GetStaticFieldID function via vtable dispatch.

func GetStaticFloatField

func GetStaticFloatField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jfloat

GetStaticFloatField wraps the JNI GetStaticFloatField function via vtable dispatch.

func GetStaticIntField

func GetStaticIntField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jint

GetStaticIntField wraps the JNI GetStaticIntField function via vtable dispatch.

func GetStaticLongField

func GetStaticLongField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jlong

GetStaticLongField wraps the JNI GetStaticLongField function via vtable dispatch.

func GetStaticMethodID

func GetStaticMethodID(env *C.JNIEnv, p0 C.jclass, p1 *C.char, p2 *C.char) C.jmethodID

GetStaticMethodID wraps the JNI GetStaticMethodID function via vtable dispatch.

func GetStaticObjectField

func GetStaticObjectField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jobject

GetStaticObjectField wraps the JNI GetStaticObjectField function via vtable dispatch.

func GetStaticShortField

func GetStaticShortField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jshort

GetStaticShortField wraps the JNI GetStaticShortField function via vtable dispatch.

func GetStringChars

func GetStringChars(env *C.JNIEnv, p0 C.jstring, p1 *C.jboolean) *C.jchar

GetStringChars wraps the JNI GetStringChars function via vtable dispatch.

func GetStringCritical

func GetStringCritical(env *C.JNIEnv, p0 C.jstring, p1 *C.jboolean) *C.jchar

GetStringCritical wraps the JNI GetStringCritical function via vtable dispatch.

func GetStringLength

func GetStringLength(env *C.JNIEnv, p0 C.jstring) C.jsize

GetStringLength wraps the JNI GetStringLength function via vtable dispatch.

func GetStringRegion

func GetStringRegion(env *C.JNIEnv, p0 C.jstring, p1 C.jsize, p2 C.jsize, p3 *C.jchar)

GetStringRegion wraps the JNI GetStringRegion function via vtable dispatch.

func GetStringUTFChars

func GetStringUTFChars(env *C.JNIEnv, p0 C.jstring, p1 *C.jboolean) *C.char

GetStringUTFChars wraps the JNI GetStringUTFChars function via vtable dispatch.

func GetStringUTFLength

func GetStringUTFLength(env *C.JNIEnv, p0 C.jstring) C.jsize

GetStringUTFLength wraps the JNI GetStringUTFLength function via vtable dispatch.

func GetStringUTFRegion

func GetStringUTFRegion(env *C.JNIEnv, p0 C.jstring, p1 C.jsize, p2 C.jsize, p3 *C.char)

GetStringUTFRegion wraps the JNI GetStringUTFRegion function via vtable dispatch.

func GetSuperclass

func GetSuperclass(env *C.JNIEnv, p0 C.jclass) C.jclass

GetSuperclass wraps the JNI GetSuperclass function via vtable dispatch.

func GetVersion

func GetVersion(env *C.JNIEnv) C.jint

GetVersion wraps the JNI GetVersion function via vtable dispatch.

func IsAssignableFrom

func IsAssignableFrom(env *C.JNIEnv, p0 C.jclass, p1 C.jclass) C.jboolean

IsAssignableFrom wraps the JNI IsAssignableFrom function via vtable dispatch.

func IsInstanceOf

func IsInstanceOf(env *C.JNIEnv, p0 C.jobject, p1 C.jclass) C.jboolean

IsInstanceOf wraps the JNI IsInstanceOf function via vtable dispatch.

func IsSameObject

func IsSameObject(env *C.JNIEnv, p0 C.jobject, p1 C.jobject) C.jboolean

IsSameObject wraps the JNI IsSameObject function via vtable dispatch.

func JvalueGetBoolean

func JvalueGetBoolean(v *C.jvalue) C.jboolean

JvalueGetBoolean gets the Boolean field of a jvalue union.

func JvalueGetByte

func JvalueGetByte(v *C.jvalue) C.jbyte

JvalueGetByte gets the Byte field of a jvalue union.

func JvalueGetChar

func JvalueGetChar(v *C.jvalue) C.jchar

JvalueGetChar gets the Char field of a jvalue union.

func JvalueGetDouble

func JvalueGetDouble(v *C.jvalue) C.jdouble

JvalueGetDouble gets the Double field of a jvalue union.

func JvalueGetFloat

func JvalueGetFloat(v *C.jvalue) C.jfloat

JvalueGetFloat gets the Float field of a jvalue union.

func JvalueGetInt

func JvalueGetInt(v *C.jvalue) C.jint

JvalueGetInt gets the Int field of a jvalue union.

func JvalueGetLong

func JvalueGetLong(v *C.jvalue) C.jlong

JvalueGetLong gets the Long field of a jvalue union.

func JvalueGetObject

func JvalueGetObject(v *C.jvalue) C.jobject

JvalueGetObject gets the Object (jobject) field of a jvalue union.

func JvalueGetShort

func JvalueGetShort(v *C.jvalue) C.jshort

JvalueGetShort gets the Short field of a jvalue union.

func JvalueSetBoolean

func JvalueSetBoolean(v *C.jvalue, val C.jboolean)

JvalueSetBoolean sets the Boolean field of a jvalue union.

func JvalueSetByte

func JvalueSetByte(v *C.jvalue, val C.jbyte)

JvalueSetByte sets the Byte field of a jvalue union.

func JvalueSetChar

func JvalueSetChar(v *C.jvalue, val C.jchar)

JvalueSetChar sets the Char field of a jvalue union.

func JvalueSetDouble

func JvalueSetDouble(v *C.jvalue, val C.jdouble)

JvalueSetDouble sets the Double field of a jvalue union.

func JvalueSetFloat

func JvalueSetFloat(v *C.jvalue, val C.jfloat)

JvalueSetFloat sets the Float field of a jvalue union.

func JvalueSetInt

func JvalueSetInt(v *C.jvalue, val C.jint)

JvalueSetInt sets the Int field of a jvalue union.

func JvalueSetLong

func JvalueSetLong(v *C.jvalue, val C.jlong)

JvalueSetLong sets the Long field of a jvalue union.

func JvalueSetObject

func JvalueSetObject(v *C.jvalue, val C.jobject)

JvalueSetObject sets the Object (jobject) field of a jvalue union.

func JvalueSetShort

func JvalueSetShort(v *C.jvalue, val C.jshort)

JvalueSetShort sets the Short field of a jvalue union.

func MonitorEnter

func MonitorEnter(env *C.JNIEnv, p0 C.jobject) C.jint

MonitorEnter wraps the JNI MonitorEnter function via vtable dispatch.

func MonitorExit

func MonitorExit(env *C.JNIEnv, p0 C.jobject) C.jint

MonitorExit wraps the JNI MonitorExit function via vtable dispatch.

func NewBooleanArray

func NewBooleanArray(env *C.JNIEnv, p0 C.jsize) C.jbooleanArray

NewBooleanArray wraps the JNI NewBooleanArray function via vtable dispatch.

func NewByteArray

func NewByteArray(env *C.JNIEnv, p0 C.jsize) C.jbyteArray

NewByteArray wraps the JNI NewByteArray function via vtable dispatch.

func NewCharArray

func NewCharArray(env *C.JNIEnv, p0 C.jsize) C.jcharArray

NewCharArray wraps the JNI NewCharArray function via vtable dispatch.

func NewDirectByteBuffer

func NewDirectByteBuffer(env *C.JNIEnv, p0 unsafe.Pointer, p1 C.jlong) C.jobject

NewDirectByteBuffer wraps the JNI NewDirectByteBuffer function via vtable dispatch.

func NewDoubleArray

func NewDoubleArray(env *C.JNIEnv, p0 C.jsize) C.jdoubleArray

NewDoubleArray wraps the JNI NewDoubleArray function via vtable dispatch.

func NewFloatArray

func NewFloatArray(env *C.JNIEnv, p0 C.jsize) C.jfloatArray

NewFloatArray wraps the JNI NewFloatArray function via vtable dispatch.

func NewGlobalRef

func NewGlobalRef(env *C.JNIEnv, p0 C.jobject) C.jobject

NewGlobalRef wraps the JNI NewGlobalRef function via vtable dispatch.

func NewIntArray

func NewIntArray(env *C.JNIEnv, p0 C.jsize) C.jintArray

NewIntArray wraps the JNI NewIntArray function via vtable dispatch.

func NewLocalRef

func NewLocalRef(env *C.JNIEnv, p0 C.jobject) C.jobject

NewLocalRef wraps the JNI NewLocalRef function via vtable dispatch.

func NewLongArray

func NewLongArray(env *C.JNIEnv, p0 C.jsize) C.jlongArray

NewLongArray wraps the JNI NewLongArray function via vtable dispatch.

func NewObjectA

func NewObjectA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jobject

NewObjectA wraps the JNI NewObjectA function via vtable dispatch.

func NewObjectArray

func NewObjectArray(env *C.JNIEnv, p0 C.jsize, p1 C.jclass, p2 C.jobject) C.jobjectArray

NewObjectArray wraps the JNI NewObjectArray function via vtable dispatch.

func NewShortArray

func NewShortArray(env *C.JNIEnv, p0 C.jsize) C.jshortArray

NewShortArray wraps the JNI NewShortArray function via vtable dispatch.

func NewString

func NewString(env *C.JNIEnv, p0 *C.jchar, p1 C.jsize) C.jstring

NewString wraps the JNI NewString function via vtable dispatch.

func NewStringUTF

func NewStringUTF(env *C.JNIEnv, p0 *C.char) C.jstring

NewStringUTF wraps the JNI NewStringUTF function via vtable dispatch.

func NewWeakGlobalRef

func NewWeakGlobalRef(env *C.JNIEnv, p0 C.jobject) C.jweak

NewWeakGlobalRef wraps the JNI NewWeakGlobalRef function via vtable dispatch.

func PopLocalFrame

func PopLocalFrame(env *C.JNIEnv, p0 C.jobject) C.jobject

PopLocalFrame wraps the JNI PopLocalFrame function via vtable dispatch.

func PushLocalFrame

func PushLocalFrame(env *C.JNIEnv, p0 C.jint) C.jint

PushLocalFrame wraps the JNI PushLocalFrame function via vtable dispatch.

func RegisterNatives

func RegisterNatives(env *C.JNIEnv, p0 C.jclass, p1 *C.JNINativeMethod, p2 C.jint) C.jint

RegisterNatives wraps the JNI RegisterNatives function via vtable dispatch.

func ReleaseBooleanArrayElements

func ReleaseBooleanArrayElements(env *C.JNIEnv, p0 C.jbooleanArray, p1 *C.jboolean, p2 C.jint)

ReleaseBooleanArrayElements wraps the JNI ReleaseBooleanArrayElements function via vtable dispatch.

func ReleaseByteArrayElements

func ReleaseByteArrayElements(env *C.JNIEnv, p0 C.jbyteArray, p1 *C.jbyte, p2 C.jint)

ReleaseByteArrayElements wraps the JNI ReleaseByteArrayElements function via vtable dispatch.

func ReleaseCharArrayElements

func ReleaseCharArrayElements(env *C.JNIEnv, p0 C.jcharArray, p1 *C.jchar, p2 C.jint)

ReleaseCharArrayElements wraps the JNI ReleaseCharArrayElements function via vtable dispatch.

func ReleaseDoubleArrayElements

func ReleaseDoubleArrayElements(env *C.JNIEnv, p0 C.jdoubleArray, p1 *C.jdouble, p2 C.jint)

ReleaseDoubleArrayElements wraps the JNI ReleaseDoubleArrayElements function via vtable dispatch.

func ReleaseFloatArrayElements

func ReleaseFloatArrayElements(env *C.JNIEnv, p0 C.jfloatArray, p1 *C.jfloat, p2 C.jint)

ReleaseFloatArrayElements wraps the JNI ReleaseFloatArrayElements function via vtable dispatch.

func ReleaseIntArrayElements

func ReleaseIntArrayElements(env *C.JNIEnv, p0 C.jintArray, p1 *C.jint, p2 C.jint)

ReleaseIntArrayElements wraps the JNI ReleaseIntArrayElements function via vtable dispatch.

func ReleaseLongArrayElements

func ReleaseLongArrayElements(env *C.JNIEnv, p0 C.jlongArray, p1 *C.jlong, p2 C.jint)

ReleaseLongArrayElements wraps the JNI ReleaseLongArrayElements function via vtable dispatch.

func ReleasePrimitiveArrayCritical

func ReleasePrimitiveArrayCritical(env *C.JNIEnv, p0 C.jarray, p1 unsafe.Pointer, p2 C.jint)

ReleasePrimitiveArrayCritical wraps the JNI ReleasePrimitiveArrayCritical function via vtable dispatch.

func ReleaseShortArrayElements

func ReleaseShortArrayElements(env *C.JNIEnv, p0 C.jshortArray, p1 *C.jshort, p2 C.jint)

ReleaseShortArrayElements wraps the JNI ReleaseShortArrayElements function via vtable dispatch.

func ReleaseStringChars

func ReleaseStringChars(env *C.JNIEnv, p0 C.jstring, p1 *C.jchar)

ReleaseStringChars wraps the JNI ReleaseStringChars function via vtable dispatch.

func ReleaseStringCritical

func ReleaseStringCritical(env *C.JNIEnv, p0 C.jstring, p1 *C.jchar)

ReleaseStringCritical wraps the JNI ReleaseStringCritical function via vtable dispatch.

func ReleaseStringUTFChars

func ReleaseStringUTFChars(env *C.JNIEnv, p0 C.jstring, p1 *C.char)

ReleaseStringUTFChars wraps the JNI ReleaseStringUTFChars function via vtable dispatch.

func SetBooleanArrayRegion

func SetBooleanArrayRegion(env *C.JNIEnv, p0 C.jbooleanArray, p1 C.jsize, p2 C.jsize, p3 *C.jboolean)

SetBooleanArrayRegion wraps the JNI SetBooleanArrayRegion function via vtable dispatch.

func SetBooleanField

func SetBooleanField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jboolean)

SetBooleanField wraps the JNI SetBooleanField function via vtable dispatch.

func SetByteArrayRegion

func SetByteArrayRegion(env *C.JNIEnv, p0 C.jbyteArray, p1 C.jsize, p2 C.jsize, p3 *C.jbyte)

SetByteArrayRegion wraps the JNI SetByteArrayRegion function via vtable dispatch.

func SetByteField

func SetByteField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jbyte)

SetByteField wraps the JNI SetByteField function via vtable dispatch.

func SetCharArrayRegion

func SetCharArrayRegion(env *C.JNIEnv, p0 C.jcharArray, p1 C.jsize, p2 C.jsize, p3 *C.jchar)

SetCharArrayRegion wraps the JNI SetCharArrayRegion function via vtable dispatch.

func SetCharField

func SetCharField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jchar)

SetCharField wraps the JNI SetCharField function via vtable dispatch.

func SetDoubleArrayRegion

func SetDoubleArrayRegion(env *C.JNIEnv, p0 C.jdoubleArray, p1 C.jsize, p2 C.jsize, p3 *C.jdouble)

SetDoubleArrayRegion wraps the JNI SetDoubleArrayRegion function via vtable dispatch.

func SetDoubleField

func SetDoubleField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jdouble)

SetDoubleField wraps the JNI SetDoubleField function via vtable dispatch.

func SetFloatArrayRegion

func SetFloatArrayRegion(env *C.JNIEnv, p0 C.jfloatArray, p1 C.jsize, p2 C.jsize, p3 *C.jfloat)

SetFloatArrayRegion wraps the JNI SetFloatArrayRegion function via vtable dispatch.

func SetFloatField

func SetFloatField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jfloat)

SetFloatField wraps the JNI SetFloatField function via vtable dispatch.

func SetIntArrayRegion

func SetIntArrayRegion(env *C.JNIEnv, p0 C.jintArray, p1 C.jsize, p2 C.jsize, p3 *C.jint)

SetIntArrayRegion wraps the JNI SetIntArrayRegion function via vtable dispatch.

func SetIntField

func SetIntField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jint)

SetIntField wraps the JNI SetIntField function via vtable dispatch.

func SetLongArrayRegion

func SetLongArrayRegion(env *C.JNIEnv, p0 C.jlongArray, p1 C.jsize, p2 C.jsize, p3 *C.jlong)

SetLongArrayRegion wraps the JNI SetLongArrayRegion function via vtable dispatch.

func SetLongField

func SetLongField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jlong)

SetLongField wraps the JNI SetLongField function via vtable dispatch.

func SetObjectArrayElement

func SetObjectArrayElement(env *C.JNIEnv, p0 C.jobjectArray, p1 C.jsize, p2 C.jobject)

SetObjectArrayElement wraps the JNI SetObjectArrayElement function via vtable dispatch.

func SetObjectField

func SetObjectField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jobject)

SetObjectField wraps the JNI SetObjectField function via vtable dispatch.

func SetShortArrayRegion

func SetShortArrayRegion(env *C.JNIEnv, p0 C.jshortArray, p1 C.jsize, p2 C.jsize, p3 *C.jshort)

SetShortArrayRegion wraps the JNI SetShortArrayRegion function via vtable dispatch.

func SetShortField

func SetShortField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jshort)

SetShortField wraps the JNI SetShortField function via vtable dispatch.

func SetStaticBooleanField

func SetStaticBooleanField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jboolean)

SetStaticBooleanField wraps the JNI SetStaticBooleanField function via vtable dispatch.

func SetStaticByteField

func SetStaticByteField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jbyte)

SetStaticByteField wraps the JNI SetStaticByteField function via vtable dispatch.

func SetStaticCharField

func SetStaticCharField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jchar)

SetStaticCharField wraps the JNI SetStaticCharField function via vtable dispatch.

func SetStaticDoubleField

func SetStaticDoubleField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jdouble)

SetStaticDoubleField wraps the JNI SetStaticDoubleField function via vtable dispatch.

func SetStaticFloatField

func SetStaticFloatField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jfloat)

SetStaticFloatField wraps the JNI SetStaticFloatField function via vtable dispatch.

func SetStaticIntField

func SetStaticIntField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jint)

SetStaticIntField wraps the JNI SetStaticIntField function via vtable dispatch.

func SetStaticLongField

func SetStaticLongField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jlong)

SetStaticLongField wraps the JNI SetStaticLongField function via vtable dispatch.

func SetStaticObjectField

func SetStaticObjectField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jobject)

SetStaticObjectField wraps the JNI SetStaticObjectField function via vtable dispatch.

func SetStaticShortField

func SetStaticShortField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jshort)

SetStaticShortField wraps the JNI SetStaticShortField function via vtable dispatch.

func Throw

func Throw(env *C.JNIEnv, p0 C.jthrowable) C.jint

Throw wraps the JNI Throw function via vtable dispatch.

func ThrowNew

func ThrowNew(env *C.JNIEnv, p0 C.jclass, p1 *C.char) C.jint

ThrowNew wraps the JNI ThrowNew function via vtable dispatch.

func ToReflectedField

func ToReflectedField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jboolean) C.jobject

ToReflectedField wraps the JNI ToReflectedField function via vtable dispatch.

func ToReflectedMethod

func ToReflectedMethod(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 C.jboolean) C.jobject

ToReflectedMethod wraps the JNI ToReflectedMethod function via vtable dispatch.

func UnregisterNatives

func UnregisterNatives(env *C.JNIEnv, p0 C.jclass) C.jint

UnregisterNatives wraps the JNI UnregisterNatives function via vtable dispatch.

Types

type Array

type Array = C.jarray

Array is the Go alias for C.jarray.

type BooleanArray

type BooleanArray = C.jbooleanArray

BooleanArray is the Go alias for C.jbooleanArray.

type ByteArray

type ByteArray = C.jbyteArray

ByteArray is the Go alias for C.jbyteArray.

type Cchar

type Cchar = C.char

Cchar is the Go alias for C.char, used in string parameters.

type CharArray

type CharArray = C.jcharArray

CharArray is the Go alias for C.jcharArray.

type Class

type Class = C.jclass

Class is the Go alias for C.jclass.

type DoubleArray

type DoubleArray = C.jdoubleArray

DoubleArray is the Go alias for C.jdoubleArray.

type Env

type Env = C.JNIEnv

Env is the Go alias for C.JNIEnv.

type FloatArray

type FloatArray = C.jfloatArray

FloatArray is the Go alias for C.jfloatArray.

type IntArray

type IntArray = C.jintArray

IntArray is the Go alias for C.jintArray.

type JNINativeMethod

type JNINativeMethod = C.JNINativeMethod

JNINativeMethod is the Go alias for C.JNINativeMethod.

type Jboolean

type Jboolean = C.jboolean

Jboolean is the Go alias for C.jboolean.

type Jbyte

type Jbyte = C.jbyte

Jbyte is the Go alias for C.jbyte.

type Jchar

type Jchar = C.jchar

Jchar is the Go alias for C.jchar.

type Jdouble

type Jdouble = C.jdouble

Jdouble is the Go alias for C.jdouble.

type JfieldID

type JfieldID = C.jfieldID

JfieldID is the Go alias for C.jfieldID.

type Jfloat

type Jfloat = C.jfloat

Jfloat is the Go alias for C.jfloat.

type Jint

type Jint = C.jint

Jint is the Go alias for C.jint.

type Jlong

type Jlong = C.jlong

Jlong is the Go alias for C.jlong.

type JmethodID

type JmethodID = C.jmethodID

JmethodID is the Go alias for C.jmethodID.

type Jshort

type Jshort = C.jshort

Jshort is the Go alias for C.jshort.

type Jsize

type Jsize = C.jsize

Jsize is the Go alias for C.jsize.

type Jvalue

type Jvalue = C.jvalue

Jvalue is the Go alias for C.jvalue.

type LongArray

type LongArray = C.jlongArray

LongArray is the Go alias for C.jlongArray.

type Object

type Object = C.jobject

Object is the Go alias for C.jobject.

type ObjectArray

type ObjectArray = C.jobjectArray

ObjectArray is the Go alias for C.jobjectArray.

type ShortArray

type ShortArray = C.jshortArray

ShortArray is the Go alias for C.jshortArray.

type String

type String = C.jstring

String is the Go alias for C.jstring.

type Throwable

type Throwable = C.jthrowable

Throwable is the Go alias for C.jthrowable.

type VM

type VM = C.JavaVM

VM is the Go alias for C.JavaVM.

type WeakRef

type WeakRef = C.jweak

WeakRef is the Go alias for C.jweak.

Jump to