Documentation
¶
Overview ¶
Desktop builds require CGO_CFLAGS and CGO_LDFLAGS pointing to a JDK:
export CGO_CFLAGS="-I$JAVA_HOME/include -I$JAVA_HOME/include/linux" export CGO_LDFLAGS="-L$JAVA_HOME/lib/server -ljvm"
Index ¶
- Constants
- func AllocObject(env *C.JNIEnv, p0 C.jclass) C.jobject
- func AttachCurrentThread(vm *C.JavaVM, p0 **C.JNIEnv, p1 unsafe.Pointer) C.jint
- func AttachCurrentThreadAsDaemon(vm *C.JavaVM, p0 **C.JNIEnv, p1 unsafe.Pointer) C.jint
- func CallBooleanMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jboolean
- func CallByteMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jbyte
- func CallCharMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jchar
- func CallDoubleMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jdouble
- func CallFloatMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jfloat
- func CallIntMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jint
- func CallLongMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jlong
- func CallNonvirtualBooleanMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jboolean
- func CallNonvirtualByteMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jbyte
- func CallNonvirtualCharMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jchar
- func CallNonvirtualDoubleMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jdouble
- func CallNonvirtualFloatMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jfloat
- func CallNonvirtualIntMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jint
- func CallNonvirtualLongMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jlong
- func CallNonvirtualObjectMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jobject
- func CallNonvirtualShortMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jshort
- func CallNonvirtualVoidMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue)
- func CallObjectMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jobject
- func CallShortMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue) C.jshort
- func CallStaticBooleanMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jboolean
- func CallStaticByteMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jbyte
- func CallStaticCharMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jchar
- func CallStaticDoubleMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jdouble
- func CallStaticFloatMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jfloat
- func CallStaticIntMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jint
- func CallStaticLongMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jlong
- func CallStaticObjectMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jobject
- func CallStaticShortMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jshort
- func CallStaticVoidMethodA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue)
- func CallVoidMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jmethodID, p2 *C.jvalue)
- func DefineClass(env *C.JNIEnv, p0 *C.char, p1 C.jobject, p2 *C.jbyte, p3 C.jsize) C.jclass
- func DeleteGlobalRef(env *C.JNIEnv, p0 C.jobject)
- func DeleteLocalRef(env *C.JNIEnv, p0 C.jobject)
- func DeleteWeakGlobalRef(env *C.JNIEnv, p0 C.jweak)
- func DestroyJavaVM(vm *C.JavaVM) C.jint
- func DetachCurrentThread(vm *C.JavaVM) C.jint
- func EnsureLocalCapacity(env *C.JNIEnv, p0 C.jint) C.jint
- func ExceptionCheck(env *C.JNIEnv) C.jboolean
- func ExceptionClear(env *C.JNIEnv)
- func ExceptionDescribe(env *C.JNIEnv)
- func ExceptionOccurred(env *C.JNIEnv) C.jthrowable
- func FatalError(env *C.JNIEnv, p0 *C.char)
- func FindClass(env *C.JNIEnv, p0 *C.char) C.jclass
- func FromReflectedField(env *C.JNIEnv, p0 C.jobject) C.jfieldID
- func FromReflectedMethod(env *C.JNIEnv, p0 C.jobject) C.jmethodID
- func GetArrayLength(env *C.JNIEnv, p0 C.jarray) C.jsize
- func GetBooleanArrayElements(env *C.JNIEnv, p0 C.jbooleanArray, p1 *C.jboolean) *C.jboolean
- func GetBooleanArrayRegion(env *C.JNIEnv, p0 C.jbooleanArray, p1 C.jsize, p2 C.jsize, p3 *C.jboolean)
- func GetBooleanField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jboolean
- func GetByteArrayElements(env *C.JNIEnv, p0 C.jbyteArray, p1 *C.jboolean) *C.jbyte
- func GetByteArrayRegion(env *C.JNIEnv, p0 C.jbyteArray, p1 C.jsize, p2 C.jsize, p3 *C.jbyte)
- func GetByteField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jbyte
- func GetCharArrayElements(env *C.JNIEnv, p0 C.jcharArray, p1 *C.jboolean) *C.jchar
- func GetCharArrayRegion(env *C.JNIEnv, p0 C.jcharArray, p1 C.jsize, p2 C.jsize, p3 *C.jchar)
- func GetCharField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jchar
- func GetDirectBufferAddress(env *C.JNIEnv, p0 C.jobject) unsafe.Pointer
- func GetDirectBufferCapacity(env *C.JNIEnv, p0 C.jobject) C.jlong
- func GetDoubleArrayElements(env *C.JNIEnv, p0 C.jdoubleArray, p1 *C.jboolean) *C.jdouble
- func GetDoubleArrayRegion(env *C.JNIEnv, p0 C.jdoubleArray, p1 C.jsize, p2 C.jsize, p3 *C.jdouble)
- func GetDoubleField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jdouble
- func GetEnv(vm *C.JavaVM, p0 *unsafe.Pointer, p1 C.jint) C.jint
- func GetFieldID(env *C.JNIEnv, p0 C.jclass, p1 *C.char, p2 *C.char) C.jfieldID
- func GetFloatArrayElements(env *C.JNIEnv, p0 C.jfloatArray, p1 *C.jboolean) *C.jfloat
- func GetFloatArrayRegion(env *C.JNIEnv, p0 C.jfloatArray, p1 C.jsize, p2 C.jsize, p3 *C.jfloat)
- func GetFloatField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jfloat
- func GetIntArrayElements(env *C.JNIEnv, p0 C.jintArray, p1 *C.jboolean) *C.jint
- func GetIntArrayRegion(env *C.JNIEnv, p0 C.jintArray, p1 C.jsize, p2 C.jsize, p3 *C.jint)
- func GetIntField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jint
- func GetLongArrayElements(env *C.JNIEnv, p0 C.jlongArray, p1 *C.jboolean) *C.jlong
- func GetLongArrayRegion(env *C.JNIEnv, p0 C.jlongArray, p1 C.jsize, p2 C.jsize, p3 *C.jlong)
- func GetLongField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jlong
- func GetMethodID(env *C.JNIEnv, p0 C.jclass, p1 *C.char, p2 *C.char) C.jmethodID
- func GetObjectArrayElement(env *C.JNIEnv, p0 C.jobjectArray, p1 C.jsize) C.jobject
- func GetObjectClass(env *C.JNIEnv, p0 C.jobject) C.jclass
- func GetObjectField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jobject
- func GetObjectRefType(env *C.JNIEnv, p0 C.jobject) C.jobjectRefType
- func GetPrimitiveArrayCritical(env *C.JNIEnv, p0 C.jarray, p1 *C.jboolean) unsafe.Pointer
- func GetShortArrayElements(env *C.JNIEnv, p0 C.jshortArray, p1 *C.jboolean) *C.jshort
- func GetShortArrayRegion(env *C.JNIEnv, p0 C.jshortArray, p1 C.jsize, p2 C.jsize, p3 *C.jshort)
- func GetShortField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID) C.jshort
- func GetStaticBooleanField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jboolean
- func GetStaticByteField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jbyte
- func GetStaticCharField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jchar
- func GetStaticDoubleField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jdouble
- func GetStaticFieldID(env *C.JNIEnv, p0 C.jclass, p1 *C.char, p2 *C.char) C.jfieldID
- func GetStaticFloatField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jfloat
- func GetStaticIntField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jint
- func GetStaticLongField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jlong
- func GetStaticMethodID(env *C.JNIEnv, p0 C.jclass, p1 *C.char, p2 *C.char) C.jmethodID
- func GetStaticObjectField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jobject
- func GetStaticShortField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID) C.jshort
- func GetStringChars(env *C.JNIEnv, p0 C.jstring, p1 *C.jboolean) *C.jchar
- func GetStringCritical(env *C.JNIEnv, p0 C.jstring, p1 *C.jboolean) *C.jchar
- func GetStringLength(env *C.JNIEnv, p0 C.jstring) C.jsize
- func GetStringRegion(env *C.JNIEnv, p0 C.jstring, p1 C.jsize, p2 C.jsize, p3 *C.jchar)
- func GetStringUTFChars(env *C.JNIEnv, p0 C.jstring, p1 *C.jboolean) *C.char
- func GetStringUTFLength(env *C.JNIEnv, p0 C.jstring) C.jsize
- func GetStringUTFRegion(env *C.JNIEnv, p0 C.jstring, p1 C.jsize, p2 C.jsize, p3 *C.char)
- func GetSuperclass(env *C.JNIEnv, p0 C.jclass) C.jclass
- func GetVersion(env *C.JNIEnv) C.jint
- func IsAssignableFrom(env *C.JNIEnv, p0 C.jclass, p1 C.jclass) C.jboolean
- func IsInstanceOf(env *C.JNIEnv, p0 C.jobject, p1 C.jclass) C.jboolean
- func IsSameObject(env *C.JNIEnv, p0 C.jobject, p1 C.jobject) C.jboolean
- func JvalueGetBoolean(v *C.jvalue) C.jboolean
- func JvalueGetByte(v *C.jvalue) C.jbyte
- func JvalueGetChar(v *C.jvalue) C.jchar
- func JvalueGetDouble(v *C.jvalue) C.jdouble
- func JvalueGetFloat(v *C.jvalue) C.jfloat
- func JvalueGetInt(v *C.jvalue) C.jint
- func JvalueGetLong(v *C.jvalue) C.jlong
- func JvalueGetObject(v *C.jvalue) C.jobject
- func JvalueGetShort(v *C.jvalue) C.jshort
- func JvalueSetBoolean(v *C.jvalue, val C.jboolean)
- func JvalueSetByte(v *C.jvalue, val C.jbyte)
- func JvalueSetChar(v *C.jvalue, val C.jchar)
- func JvalueSetDouble(v *C.jvalue, val C.jdouble)
- func JvalueSetFloat(v *C.jvalue, val C.jfloat)
- func JvalueSetInt(v *C.jvalue, val C.jint)
- func JvalueSetLong(v *C.jvalue, val C.jlong)
- func JvalueSetObject(v *C.jvalue, val C.jobject)
- func JvalueSetShort(v *C.jvalue, val C.jshort)
- func MonitorEnter(env *C.JNIEnv, p0 C.jobject) C.jint
- func MonitorExit(env *C.JNIEnv, p0 C.jobject) C.jint
- func NewBooleanArray(env *C.JNIEnv, p0 C.jsize) C.jbooleanArray
- func NewByteArray(env *C.JNIEnv, p0 C.jsize) C.jbyteArray
- func NewCharArray(env *C.JNIEnv, p0 C.jsize) C.jcharArray
- func NewDirectByteBuffer(env *C.JNIEnv, p0 unsafe.Pointer, p1 C.jlong) C.jobject
- func NewDoubleArray(env *C.JNIEnv, p0 C.jsize) C.jdoubleArray
- func NewFloatArray(env *C.JNIEnv, p0 C.jsize) C.jfloatArray
- func NewGlobalRef(env *C.JNIEnv, p0 C.jobject) C.jobject
- func NewIntArray(env *C.JNIEnv, p0 C.jsize) C.jintArray
- func NewLocalRef(env *C.JNIEnv, p0 C.jobject) C.jobject
- func NewLongArray(env *C.JNIEnv, p0 C.jsize) C.jlongArray
- func NewObjectA(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 *C.jvalue) C.jobject
- func NewObjectArray(env *C.JNIEnv, p0 C.jsize, p1 C.jclass, p2 C.jobject) C.jobjectArray
- func NewShortArray(env *C.JNIEnv, p0 C.jsize) C.jshortArray
- func NewString(env *C.JNIEnv, p0 *C.jchar, p1 C.jsize) C.jstring
- func NewStringUTF(env *C.JNIEnv, p0 *C.char) C.jstring
- func NewWeakGlobalRef(env *C.JNIEnv, p0 C.jobject) C.jweak
- func PopLocalFrame(env *C.JNIEnv, p0 C.jobject) C.jobject
- func PushLocalFrame(env *C.JNIEnv, p0 C.jint) C.jint
- func RegisterNatives(env *C.JNIEnv, p0 C.jclass, p1 *C.JNINativeMethod, p2 C.jint) C.jint
- func ReleaseBooleanArrayElements(env *C.JNIEnv, p0 C.jbooleanArray, p1 *C.jboolean, p2 C.jint)
- func ReleaseByteArrayElements(env *C.JNIEnv, p0 C.jbyteArray, p1 *C.jbyte, p2 C.jint)
- func ReleaseCharArrayElements(env *C.JNIEnv, p0 C.jcharArray, p1 *C.jchar, p2 C.jint)
- func ReleaseDoubleArrayElements(env *C.JNIEnv, p0 C.jdoubleArray, p1 *C.jdouble, p2 C.jint)
- func ReleaseFloatArrayElements(env *C.JNIEnv, p0 C.jfloatArray, p1 *C.jfloat, p2 C.jint)
- func ReleaseIntArrayElements(env *C.JNIEnv, p0 C.jintArray, p1 *C.jint, p2 C.jint)
- func ReleaseLongArrayElements(env *C.JNIEnv, p0 C.jlongArray, p1 *C.jlong, p2 C.jint)
- func ReleasePrimitiveArrayCritical(env *C.JNIEnv, p0 C.jarray, p1 unsafe.Pointer, p2 C.jint)
- func ReleaseShortArrayElements(env *C.JNIEnv, p0 C.jshortArray, p1 *C.jshort, p2 C.jint)
- func ReleaseStringChars(env *C.JNIEnv, p0 C.jstring, p1 *C.jchar)
- func ReleaseStringCritical(env *C.JNIEnv, p0 C.jstring, p1 *C.jchar)
- func ReleaseStringUTFChars(env *C.JNIEnv, p0 C.jstring, p1 *C.char)
- func SetBooleanArrayRegion(env *C.JNIEnv, p0 C.jbooleanArray, p1 C.jsize, p2 C.jsize, p3 *C.jboolean)
- func SetBooleanField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jboolean)
- func SetByteArrayRegion(env *C.JNIEnv, p0 C.jbyteArray, p1 C.jsize, p2 C.jsize, p3 *C.jbyte)
- func SetByteField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jbyte)
- func SetCharArrayRegion(env *C.JNIEnv, p0 C.jcharArray, p1 C.jsize, p2 C.jsize, p3 *C.jchar)
- func SetCharField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jchar)
- func SetDoubleArrayRegion(env *C.JNIEnv, p0 C.jdoubleArray, p1 C.jsize, p2 C.jsize, p3 *C.jdouble)
- func SetDoubleField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jdouble)
- func SetFloatArrayRegion(env *C.JNIEnv, p0 C.jfloatArray, p1 C.jsize, p2 C.jsize, p3 *C.jfloat)
- func SetFloatField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jfloat)
- func SetIntArrayRegion(env *C.JNIEnv, p0 C.jintArray, p1 C.jsize, p2 C.jsize, p3 *C.jint)
- func SetIntField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jint)
- func SetLongArrayRegion(env *C.JNIEnv, p0 C.jlongArray, p1 C.jsize, p2 C.jsize, p3 *C.jlong)
- func SetLongField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jlong)
- func SetObjectArrayElement(env *C.JNIEnv, p0 C.jobjectArray, p1 C.jsize, p2 C.jobject)
- func SetObjectField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jobject)
- func SetShortArrayRegion(env *C.JNIEnv, p0 C.jshortArray, p1 C.jsize, p2 C.jsize, p3 *C.jshort)
- func SetShortField(env *C.JNIEnv, p0 C.jobject, p1 C.jfieldID, p2 C.jshort)
- func SetStaticBooleanField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jboolean)
- func SetStaticByteField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jbyte)
- func SetStaticCharField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jchar)
- func SetStaticDoubleField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jdouble)
- func SetStaticFloatField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jfloat)
- func SetStaticIntField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jint)
- func SetStaticLongField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jlong)
- func SetStaticObjectField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jobject)
- func SetStaticShortField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jshort)
- func Throw(env *C.JNIEnv, p0 C.jthrowable) C.jint
- func ThrowNew(env *C.JNIEnv, p0 C.jclass, p1 *C.char) C.jint
- func ToReflectedField(env *C.JNIEnv, p0 C.jclass, p1 C.jfieldID, p2 C.jboolean) C.jobject
- func ToReflectedMethod(env *C.JNIEnv, p0 C.jclass, p1 C.jmethodID, p2 C.jboolean) C.jobject
- func UnregisterNatives(env *C.JNIEnv, p0 C.jclass) C.jint
- type Array
- type BooleanArray
- type ByteArray
- type Cchar
- type CharArray
- type Class
- type DoubleArray
- type Env
- type FloatArray
- type IntArray
- type JNINativeMethod
- type Jboolean
- type Jbyte
- type Jchar
- type Jdouble
- type JfieldID
- type Jfloat
- type Jint
- type Jlong
- type JmethodID
- type Jshort
- type Jsize
- type Jvalue
- type LongArray
- type Object
- type ObjectArray
- type ShortArray
- type String
- type Throwable
- type VM
- type WeakRef
Constants ¶
const ( JNI_OK = 0 JNI_ERR = -1 JNI_EDETACHED = -2 JNI_EVERSION = -3 JNI_ENOMEM = -4 JNI_EEXIST = -5 JNI_EINVAL = -6 JNI_VERSION_1_1 = 0x00010001 JNI_VERSION_1_2 = 0x00010002 JNI_VERSION_1_4 = 0x00010004 JNI_VERSION_1_6 = 0x00010006 JNI_VERSION_1_8 = 0x00010008 JNI_VERSION_9 = 0x00090000 JNI_VERSION_10 = 0x000a0000 JNI_VERSION_19 = 0x00130000 JNI_VERSION_20 = 0x00140000 JNI_VERSION_21 = 0x00150000 JNI_COMMIT = 1 JNI_ABORT = 2 JNI_FALSE = 0 JNI_TRUE = 1 JNIInvalidRefType = 0 JNILocalRefType = 1 JNIGlobalRefType = 2 JNIWeakGlobalRefType = 3 )
Variables ¶
This section is empty.
Functions ¶
func AllocObject ¶
AllocObject wraps the JNI AllocObject function via vtable dispatch.
func AttachCurrentThread ¶
AttachCurrentThread wraps the JNI AttachCurrentThread function via vtable dispatch.
func AttachCurrentThreadAsDaemon ¶
AttachCurrentThreadAsDaemon wraps the JNI AttachCurrentThreadAsDaemon function via vtable dispatch.
func CallBooleanMethodA ¶
CallBooleanMethodA wraps the JNI CallBooleanMethodA function via vtable dispatch.
func CallByteMethodA ¶
CallByteMethodA wraps the JNI CallByteMethodA function via vtable dispatch.
func CallCharMethodA ¶
CallCharMethodA wraps the JNI CallCharMethodA function via vtable dispatch.
func CallDoubleMethodA ¶
CallDoubleMethodA wraps the JNI CallDoubleMethodA function via vtable dispatch.
func CallFloatMethodA ¶
CallFloatMethodA wraps the JNI CallFloatMethodA function via vtable dispatch.
func CallIntMethodA ¶
CallIntMethodA wraps the JNI CallIntMethodA function via vtable dispatch.
func CallLongMethodA ¶
CallLongMethodA wraps the JNI CallLongMethodA function via vtable dispatch.
func CallNonvirtualBooleanMethodA ¶
func CallNonvirtualBooleanMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jboolean
CallNonvirtualBooleanMethodA wraps the JNI CallNonvirtualBooleanMethodA function via vtable dispatch.
func CallNonvirtualByteMethodA ¶
func CallNonvirtualByteMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jbyte
CallNonvirtualByteMethodA wraps the JNI CallNonvirtualByteMethodA function via vtable dispatch.
func CallNonvirtualCharMethodA ¶
func CallNonvirtualCharMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jchar
CallNonvirtualCharMethodA wraps the JNI CallNonvirtualCharMethodA function via vtable dispatch.
func CallNonvirtualDoubleMethodA ¶
func CallNonvirtualDoubleMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jdouble
CallNonvirtualDoubleMethodA wraps the JNI CallNonvirtualDoubleMethodA function via vtable dispatch.
func CallNonvirtualFloatMethodA ¶
func CallNonvirtualFloatMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jfloat
CallNonvirtualFloatMethodA wraps the JNI CallNonvirtualFloatMethodA function via vtable dispatch.
func CallNonvirtualIntMethodA ¶
func CallNonvirtualIntMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jint
CallNonvirtualIntMethodA wraps the JNI CallNonvirtualIntMethodA function via vtable dispatch.
func CallNonvirtualLongMethodA ¶
func CallNonvirtualLongMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jlong
CallNonvirtualLongMethodA wraps the JNI CallNonvirtualLongMethodA function via vtable dispatch.
func CallNonvirtualObjectMethodA ¶
func CallNonvirtualObjectMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jobject
CallNonvirtualObjectMethodA wraps the JNI CallNonvirtualObjectMethodA function via vtable dispatch.
func CallNonvirtualShortMethodA ¶
func CallNonvirtualShortMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue) C.jshort
CallNonvirtualShortMethodA wraps the JNI CallNonvirtualShortMethodA function via vtable dispatch.
func CallNonvirtualVoidMethodA ¶
func CallNonvirtualVoidMethodA(env *C.JNIEnv, p0 C.jobject, p1 C.jclass, p2 C.jmethodID, p3 *C.jvalue)
CallNonvirtualVoidMethodA wraps the JNI CallNonvirtualVoidMethodA function via vtable dispatch.
func CallObjectMethodA ¶
CallObjectMethodA wraps the JNI CallObjectMethodA function via vtable dispatch.
func CallShortMethodA ¶
CallShortMethodA wraps the JNI CallShortMethodA function via vtable dispatch.
func CallStaticBooleanMethodA ¶
CallStaticBooleanMethodA wraps the JNI CallStaticBooleanMethodA function via vtable dispatch.
func CallStaticByteMethodA ¶
CallStaticByteMethodA wraps the JNI CallStaticByteMethodA function via vtable dispatch.
func CallStaticCharMethodA ¶
CallStaticCharMethodA wraps the JNI CallStaticCharMethodA function via vtable dispatch.
func CallStaticDoubleMethodA ¶
CallStaticDoubleMethodA wraps the JNI CallStaticDoubleMethodA function via vtable dispatch.
func CallStaticFloatMethodA ¶
CallStaticFloatMethodA wraps the JNI CallStaticFloatMethodA function via vtable dispatch.
func CallStaticIntMethodA ¶
CallStaticIntMethodA wraps the JNI CallStaticIntMethodA function via vtable dispatch.
func CallStaticLongMethodA ¶
CallStaticLongMethodA wraps the JNI CallStaticLongMethodA function via vtable dispatch.
func CallStaticObjectMethodA ¶
CallStaticObjectMethodA wraps the JNI CallStaticObjectMethodA function via vtable dispatch.
func CallStaticShortMethodA ¶
CallStaticShortMethodA wraps the JNI CallStaticShortMethodA function via vtable dispatch.
func CallStaticVoidMethodA ¶
CallStaticVoidMethodA wraps the JNI CallStaticVoidMethodA function via vtable dispatch.
func CallVoidMethodA ¶
CallVoidMethodA wraps the JNI CallVoidMethodA function via vtable dispatch.
func DefineClass ¶
DefineClass wraps the JNI DefineClass function via vtable dispatch.
func DeleteGlobalRef ¶
DeleteGlobalRef wraps the JNI DeleteGlobalRef function via vtable dispatch.
func DeleteLocalRef ¶
DeleteLocalRef wraps the JNI DeleteLocalRef function via vtable dispatch.
func DeleteWeakGlobalRef ¶
DeleteWeakGlobalRef wraps the JNI DeleteWeakGlobalRef function via vtable dispatch.
func DestroyJavaVM ¶
DestroyJavaVM wraps the JNI DestroyJavaVM function via vtable dispatch.
func DetachCurrentThread ¶
DetachCurrentThread wraps the JNI DetachCurrentThread function via vtable dispatch.
func EnsureLocalCapacity ¶
EnsureLocalCapacity wraps the JNI EnsureLocalCapacity function via vtable dispatch.
func ExceptionCheck ¶
ExceptionCheck wraps the JNI ExceptionCheck function via vtable dispatch.
func ExceptionClear ¶
ExceptionClear wraps the JNI ExceptionClear function via vtable dispatch.
func ExceptionDescribe ¶
ExceptionDescribe wraps the JNI ExceptionDescribe function via vtable dispatch.
func ExceptionOccurred ¶
func ExceptionOccurred(env *C.JNIEnv) C.jthrowable
ExceptionOccurred wraps the JNI ExceptionOccurred function via vtable dispatch.
func FatalError ¶
FatalError wraps the JNI FatalError function via vtable dispatch.
func FromReflectedField ¶
FromReflectedField wraps the JNI FromReflectedField function via vtable dispatch.
func FromReflectedMethod ¶
FromReflectedMethod wraps the JNI FromReflectedMethod function via vtable dispatch.
func GetArrayLength ¶
GetArrayLength wraps the JNI GetArrayLength function via vtable dispatch.
func GetBooleanArrayElements ¶
GetBooleanArrayElements wraps the JNI GetBooleanArrayElements function via vtable dispatch.
func GetBooleanArrayRegion ¶
func GetBooleanArrayRegion(env *C.JNIEnv, p0 C.jbooleanArray, p1 C.jsize, p2 C.jsize, p3 *C.jboolean)
GetBooleanArrayRegion wraps the JNI GetBooleanArrayRegion function via vtable dispatch.
func GetBooleanField ¶
GetBooleanField wraps the JNI GetBooleanField function via vtable dispatch.
func GetByteArrayElements ¶
GetByteArrayElements wraps the JNI GetByteArrayElements function via vtable dispatch.
func GetByteArrayRegion ¶
GetByteArrayRegion wraps the JNI GetByteArrayRegion function via vtable dispatch.
func GetByteField ¶
GetByteField wraps the JNI GetByteField function via vtable dispatch.
func GetCharArrayElements ¶
GetCharArrayElements wraps the JNI GetCharArrayElements function via vtable dispatch.
func GetCharArrayRegion ¶
GetCharArrayRegion wraps the JNI GetCharArrayRegion function via vtable dispatch.
func GetCharField ¶
GetCharField wraps the JNI GetCharField function via vtable dispatch.
func GetDirectBufferAddress ¶
GetDirectBufferAddress wraps the JNI GetDirectBufferAddress function via vtable dispatch.
func GetDirectBufferCapacity ¶
GetDirectBufferCapacity wraps the JNI GetDirectBufferCapacity function via vtable dispatch.
func GetDoubleArrayElements ¶
GetDoubleArrayElements wraps the JNI GetDoubleArrayElements function via vtable dispatch.
func GetDoubleArrayRegion ¶
GetDoubleArrayRegion wraps the JNI GetDoubleArrayRegion function via vtable dispatch.
func GetDoubleField ¶
GetDoubleField wraps the JNI GetDoubleField function via vtable dispatch.
func GetFieldID ¶
GetFieldID wraps the JNI GetFieldID function via vtable dispatch.
func GetFloatArrayElements ¶
GetFloatArrayElements wraps the JNI GetFloatArrayElements function via vtable dispatch.
func GetFloatArrayRegion ¶
GetFloatArrayRegion wraps the JNI GetFloatArrayRegion function via vtable dispatch.
func GetFloatField ¶
GetFloatField wraps the JNI GetFloatField function via vtable dispatch.
func GetIntArrayElements ¶
GetIntArrayElements wraps the JNI GetIntArrayElements function via vtable dispatch.
func GetIntArrayRegion ¶
GetIntArrayRegion wraps the JNI GetIntArrayRegion function via vtable dispatch.
func GetIntField ¶
GetIntField wraps the JNI GetIntField function via vtable dispatch.
func GetLongArrayElements ¶
GetLongArrayElements wraps the JNI GetLongArrayElements function via vtable dispatch.
func GetLongArrayRegion ¶
GetLongArrayRegion wraps the JNI GetLongArrayRegion function via vtable dispatch.
func GetLongField ¶
GetLongField wraps the JNI GetLongField function via vtable dispatch.
func GetMethodID ¶
GetMethodID wraps the JNI GetMethodID function via vtable dispatch.
func GetObjectArrayElement ¶
GetObjectArrayElement wraps the JNI GetObjectArrayElement function via vtable dispatch.
func GetObjectClass ¶
GetObjectClass wraps the JNI GetObjectClass function via vtable dispatch.
func GetObjectField ¶
GetObjectField wraps the JNI GetObjectField function via vtable dispatch.
func GetObjectRefType ¶
GetObjectRefType wraps the JNI GetObjectRefType function via vtable dispatch.
func GetPrimitiveArrayCritical ¶
GetPrimitiveArrayCritical wraps the JNI GetPrimitiveArrayCritical function via vtable dispatch.
func GetShortArrayElements ¶
GetShortArrayElements wraps the JNI GetShortArrayElements function via vtable dispatch.
func GetShortArrayRegion ¶
GetShortArrayRegion wraps the JNI GetShortArrayRegion function via vtable dispatch.
func GetShortField ¶
GetShortField wraps the JNI GetShortField function via vtable dispatch.
func GetStaticBooleanField ¶
GetStaticBooleanField wraps the JNI GetStaticBooleanField function via vtable dispatch.
func GetStaticByteField ¶
GetStaticByteField wraps the JNI GetStaticByteField function via vtable dispatch.
func GetStaticCharField ¶
GetStaticCharField wraps the JNI GetStaticCharField function via vtable dispatch.
func GetStaticDoubleField ¶
GetStaticDoubleField wraps the JNI GetStaticDoubleField function via vtable dispatch.
func GetStaticFieldID ¶
GetStaticFieldID wraps the JNI GetStaticFieldID function via vtable dispatch.
func GetStaticFloatField ¶
GetStaticFloatField wraps the JNI GetStaticFloatField function via vtable dispatch.
func GetStaticIntField ¶
GetStaticIntField wraps the JNI GetStaticIntField function via vtable dispatch.
func GetStaticLongField ¶
GetStaticLongField wraps the JNI GetStaticLongField function via vtable dispatch.
func GetStaticMethodID ¶
GetStaticMethodID wraps the JNI GetStaticMethodID function via vtable dispatch.
func GetStaticObjectField ¶
GetStaticObjectField wraps the JNI GetStaticObjectField function via vtable dispatch.
func GetStaticShortField ¶
GetStaticShortField wraps the JNI GetStaticShortField function via vtable dispatch.
func GetStringChars ¶
GetStringChars wraps the JNI GetStringChars function via vtable dispatch.
func GetStringCritical ¶
GetStringCritical wraps the JNI GetStringCritical function via vtable dispatch.
func GetStringLength ¶
GetStringLength wraps the JNI GetStringLength function via vtable dispatch.
func GetStringRegion ¶
GetStringRegion wraps the JNI GetStringRegion function via vtable dispatch.
func GetStringUTFChars ¶
GetStringUTFChars wraps the JNI GetStringUTFChars function via vtable dispatch.
func GetStringUTFLength ¶
GetStringUTFLength wraps the JNI GetStringUTFLength function via vtable dispatch.
func GetStringUTFRegion ¶
GetStringUTFRegion wraps the JNI GetStringUTFRegion function via vtable dispatch.
func GetSuperclass ¶
GetSuperclass wraps the JNI GetSuperclass function via vtable dispatch.
func GetVersion ¶
GetVersion wraps the JNI GetVersion function via vtable dispatch.
func IsAssignableFrom ¶
IsAssignableFrom wraps the JNI IsAssignableFrom function via vtable dispatch.
func IsInstanceOf ¶
IsInstanceOf wraps the JNI IsInstanceOf function via vtable dispatch.
func IsSameObject ¶
IsSameObject wraps the JNI IsSameObject function via vtable dispatch.
func JvalueGetBoolean ¶
JvalueGetBoolean gets the Boolean field of a jvalue union.
func JvalueGetByte ¶
JvalueGetByte gets the Byte field of a jvalue union.
func JvalueGetChar ¶
JvalueGetChar gets the Char field of a jvalue union.
func JvalueGetDouble ¶
JvalueGetDouble gets the Double field of a jvalue union.
func JvalueGetFloat ¶
JvalueGetFloat gets the Float field of a jvalue union.
func JvalueGetInt ¶
JvalueGetInt gets the Int field of a jvalue union.
func JvalueGetLong ¶
JvalueGetLong gets the Long field of a jvalue union.
func JvalueGetObject ¶
JvalueGetObject gets the Object (jobject) field of a jvalue union.
func JvalueGetShort ¶
JvalueGetShort gets the Short field of a jvalue union.
func JvalueSetBoolean ¶
JvalueSetBoolean sets the Boolean field of a jvalue union.
func JvalueSetByte ¶
JvalueSetByte sets the Byte field of a jvalue union.
func JvalueSetChar ¶
JvalueSetChar sets the Char field of a jvalue union.
func JvalueSetDouble ¶
JvalueSetDouble sets the Double field of a jvalue union.
func JvalueSetFloat ¶
JvalueSetFloat sets the Float field of a jvalue union.
func JvalueSetInt ¶
JvalueSetInt sets the Int field of a jvalue union.
func JvalueSetLong ¶
JvalueSetLong sets the Long field of a jvalue union.
func JvalueSetObject ¶
JvalueSetObject sets the Object (jobject) field of a jvalue union.
func JvalueSetShort ¶
JvalueSetShort sets the Short field of a jvalue union.
func MonitorEnter ¶
MonitorEnter wraps the JNI MonitorEnter function via vtable dispatch.
func MonitorExit ¶
MonitorExit wraps the JNI MonitorExit function via vtable dispatch.
func NewBooleanArray ¶
NewBooleanArray wraps the JNI NewBooleanArray function via vtable dispatch.
func NewByteArray ¶
NewByteArray wraps the JNI NewByteArray function via vtable dispatch.
func NewCharArray ¶
NewCharArray wraps the JNI NewCharArray function via vtable dispatch.
func NewDirectByteBuffer ¶
NewDirectByteBuffer wraps the JNI NewDirectByteBuffer function via vtable dispatch.
func NewDoubleArray ¶
NewDoubleArray wraps the JNI NewDoubleArray function via vtable dispatch.
func NewFloatArray ¶
NewFloatArray wraps the JNI NewFloatArray function via vtable dispatch.
func NewGlobalRef ¶
NewGlobalRef wraps the JNI NewGlobalRef function via vtable dispatch.
func NewIntArray ¶
NewIntArray wraps the JNI NewIntArray function via vtable dispatch.
func NewLocalRef ¶
NewLocalRef wraps the JNI NewLocalRef function via vtable dispatch.
func NewLongArray ¶
NewLongArray wraps the JNI NewLongArray function via vtable dispatch.
func NewObjectA ¶
NewObjectA wraps the JNI NewObjectA function via vtable dispatch.
func NewObjectArray ¶
NewObjectArray wraps the JNI NewObjectArray function via vtable dispatch.
func NewShortArray ¶
NewShortArray wraps the JNI NewShortArray function via vtable dispatch.
func NewStringUTF ¶
NewStringUTF wraps the JNI NewStringUTF function via vtable dispatch.
func NewWeakGlobalRef ¶
NewWeakGlobalRef wraps the JNI NewWeakGlobalRef function via vtable dispatch.
func PopLocalFrame ¶
PopLocalFrame wraps the JNI PopLocalFrame function via vtable dispatch.
func PushLocalFrame ¶
PushLocalFrame wraps the JNI PushLocalFrame function via vtable dispatch.
func RegisterNatives ¶
RegisterNatives wraps the JNI RegisterNatives function via vtable dispatch.
func ReleaseBooleanArrayElements ¶
ReleaseBooleanArrayElements wraps the JNI ReleaseBooleanArrayElements function via vtable dispatch.
func ReleaseByteArrayElements ¶
ReleaseByteArrayElements wraps the JNI ReleaseByteArrayElements function via vtable dispatch.
func ReleaseCharArrayElements ¶
ReleaseCharArrayElements wraps the JNI ReleaseCharArrayElements function via vtable dispatch.
func ReleaseDoubleArrayElements ¶
ReleaseDoubleArrayElements wraps the JNI ReleaseDoubleArrayElements function via vtable dispatch.
func ReleaseFloatArrayElements ¶
ReleaseFloatArrayElements wraps the JNI ReleaseFloatArrayElements function via vtable dispatch.
func ReleaseIntArrayElements ¶
ReleaseIntArrayElements wraps the JNI ReleaseIntArrayElements function via vtable dispatch.
func ReleaseLongArrayElements ¶
ReleaseLongArrayElements wraps the JNI ReleaseLongArrayElements function via vtable dispatch.
func ReleasePrimitiveArrayCritical ¶
ReleasePrimitiveArrayCritical wraps the JNI ReleasePrimitiveArrayCritical function via vtable dispatch.
func ReleaseShortArrayElements ¶
ReleaseShortArrayElements wraps the JNI ReleaseShortArrayElements function via vtable dispatch.
func ReleaseStringChars ¶
ReleaseStringChars wraps the JNI ReleaseStringChars function via vtable dispatch.
func ReleaseStringCritical ¶
ReleaseStringCritical wraps the JNI ReleaseStringCritical function via vtable dispatch.
func ReleaseStringUTFChars ¶
ReleaseStringUTFChars wraps the JNI ReleaseStringUTFChars function via vtable dispatch.
func SetBooleanArrayRegion ¶
func SetBooleanArrayRegion(env *C.JNIEnv, p0 C.jbooleanArray, p1 C.jsize, p2 C.jsize, p3 *C.jboolean)
SetBooleanArrayRegion wraps the JNI SetBooleanArrayRegion function via vtable dispatch.
func SetBooleanField ¶
SetBooleanField wraps the JNI SetBooleanField function via vtable dispatch.
func SetByteArrayRegion ¶
SetByteArrayRegion wraps the JNI SetByteArrayRegion function via vtable dispatch.
func SetByteField ¶
SetByteField wraps the JNI SetByteField function via vtable dispatch.
func SetCharArrayRegion ¶
SetCharArrayRegion wraps the JNI SetCharArrayRegion function via vtable dispatch.
func SetCharField ¶
SetCharField wraps the JNI SetCharField function via vtable dispatch.
func SetDoubleArrayRegion ¶
SetDoubleArrayRegion wraps the JNI SetDoubleArrayRegion function via vtable dispatch.
func SetDoubleField ¶
SetDoubleField wraps the JNI SetDoubleField function via vtable dispatch.
func SetFloatArrayRegion ¶
SetFloatArrayRegion wraps the JNI SetFloatArrayRegion function via vtable dispatch.
func SetFloatField ¶
SetFloatField wraps the JNI SetFloatField function via vtable dispatch.
func SetIntArrayRegion ¶
SetIntArrayRegion wraps the JNI SetIntArrayRegion function via vtable dispatch.
func SetIntField ¶
SetIntField wraps the JNI SetIntField function via vtable dispatch.
func SetLongArrayRegion ¶
SetLongArrayRegion wraps the JNI SetLongArrayRegion function via vtable dispatch.
func SetLongField ¶
SetLongField wraps the JNI SetLongField function via vtable dispatch.
func SetObjectArrayElement ¶
SetObjectArrayElement wraps the JNI SetObjectArrayElement function via vtable dispatch.
func SetObjectField ¶
SetObjectField wraps the JNI SetObjectField function via vtable dispatch.
func SetShortArrayRegion ¶
SetShortArrayRegion wraps the JNI SetShortArrayRegion function via vtable dispatch.
func SetShortField ¶
SetShortField wraps the JNI SetShortField function via vtable dispatch.
func SetStaticBooleanField ¶
SetStaticBooleanField wraps the JNI SetStaticBooleanField function via vtable dispatch.
func SetStaticByteField ¶
SetStaticByteField wraps the JNI SetStaticByteField function via vtable dispatch.
func SetStaticCharField ¶
SetStaticCharField wraps the JNI SetStaticCharField function via vtable dispatch.
func SetStaticDoubleField ¶
SetStaticDoubleField wraps the JNI SetStaticDoubleField function via vtable dispatch.
func SetStaticFloatField ¶
SetStaticFloatField wraps the JNI SetStaticFloatField function via vtable dispatch.
func SetStaticIntField ¶
SetStaticIntField wraps the JNI SetStaticIntField function via vtable dispatch.
func SetStaticLongField ¶
SetStaticLongField wraps the JNI SetStaticLongField function via vtable dispatch.
func SetStaticObjectField ¶
SetStaticObjectField wraps the JNI SetStaticObjectField function via vtable dispatch.
func SetStaticShortField ¶
SetStaticShortField wraps the JNI SetStaticShortField function via vtable dispatch.
func ToReflectedField ¶
ToReflectedField wraps the JNI ToReflectedField function via vtable dispatch.
func ToReflectedMethod ¶
ToReflectedMethod wraps the JNI ToReflectedMethod function via vtable dispatch.
Types ¶
type BooleanArray ¶
type BooleanArray = C.jbooleanArray
BooleanArray is the Go alias for C.jbooleanArray.
type DoubleArray ¶
type DoubleArray = C.jdoubleArray
DoubleArray is the Go alias for C.jdoubleArray.
type JNINativeMethod ¶
type JNINativeMethod = C.JNINativeMethod
JNINativeMethod is the Go alias for C.JNINativeMethod.
type ObjectArray ¶
type ObjectArray = C.jobjectArray
ObjectArray is the Go alias for C.jobjectArray.